@@ -18,13 +18,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
 #endif
 
 #include <KConfigGroup>
-#include <KLocalizedString>
 #include <KMessageBox>
 #include <QAction>
 #include <QBoxLayout>
@@ -87,7 +87,7 @@ DvbChannelTableModel::~DvbChannelTableModel()
 void DvbChannelTableModel::setChannelModel(DvbChannelModel *channelModel_)
 {
 	if (channelModel != NULL) {
-		qInfo() << "DvbChannelTableModel::setChannelModel: channel model already set";
+		qWarning("Channel model already set");
 		return;
 	}
 
@@ -127,15 +127,15 @@ QVariant DvbChannelTableModel::data(const QModelIndex &index, int role) const
 			if (index.column() == 0) {
 				if (channel->hasVideo) {
 					if (!channel->isScrambled) {
-						return QIcon::fromTheme(QLatin1String("video-television"));
+						return QIcon::fromTheme(QLatin1String("video-television"), QIcon(":video-television"));
 					} else {
-						return QIcon::fromTheme(QLatin1String("video-television-encrypted"));
+						return QIcon::fromTheme(QLatin1String("video-television-encrypted"), QIcon(":video-television-encrypted"));
 					}
 				} else {
 					if (!channel->isScrambled) {
-						return QIcon::fromTheme(QLatin1String("text-speak"));
+						return QIcon::fromTheme(QLatin1String("text-speak"), QIcon(":text-speak"));
 					} else {
-						return QIcon::fromTheme(QLatin1String("audio-radio-encrypted"));
+						return QIcon::fromTheme(QLatin1String("audio-radio-encrypted"), QIcon(":audio-radio-encrypted"));
 					}
 				}
 			}
@@ -292,7 +292,7 @@ DvbChannelView::~DvbChannelView()
 
 QAction *DvbChannelView::addEditAction()
 {
-	QAction *action = new QAction(QIcon::fromTheme(QLatin1String("configure")), i18nc("@action", "Edit"), this);
+	QAction *action = new QAction(QIcon::fromTheme(QLatin1String("configure"), QIcon(":configure")), i18nc("@action", "Edit"), this);
 	connect(action, SIGNAL(triggered()), this, SLOT(editChannel()));
 	addAction(action);
 	return action;
@@ -300,7 +300,7 @@ QAction *DvbChannelView::addEditAction()
 
 QAction *DvbChannelView::addRemoveAction()
 {
-	QAction *action = new QAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18nc("@action", "Remove"), this);
+	QAction *action = new QAction(QIcon::fromTheme(QLatin1String("edit-delete"), QIcon(":edit-delete")), i18nc("@action", "Remove"), this);
 	connect(action, SIGNAL(triggered()), this, SLOT(removeChannel()));
 	addAction(action);
 	return action;
@@ -412,6 +412,7 @@ static QString enumToString(DvbSTransponder::Polarization polarization)
 	case DvbSTransponder::Vertical: return i18n("Vertical");
 	case DvbSTransponder::CircularLeft: return i18n("Circular left");
 	case DvbSTransponder::CircularRight: return i18n("Circular right");
+	case DvbSTransponder::Off: return i18n("Off");
 	}
 
 	return QString();
