@@ -192,6 +192,7 @@ private:
 	QSpinBox *timeoutBox;
 	QComboBox *sourceBox;
 	QLineEdit *nameEdit;
+	bool isGen2;
 };
 
 class DvbSConfigObject : public QObject
@@ -199,13 +200,14 @@ class DvbSConfigObject : public QObject
 	Q_OBJECT
 public:
 	DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbManager *manager,
-		const QList<DvbConfig> &configs, DvbDevice *device, bool dvbS2);
+		const QList<DvbConfig> &configs, DvbDevice *device, bool isGen2);
 	~DvbSConfigObject();
 
 	void appendConfigs(QList<DvbConfig> &list);
 
 signals:
 	void setDiseqcVisible(bool visible);
+	void setFirstLnbVisible(bool visible);
 	void setRotorVisible(bool visible); // common parts of usals / positions ui
 	void setUsalsVisible(bool visible); // usals-specific parts of ui
 	void setPositionsVisible(bool visible); // positions-specific parts of ui
