@@ -312,10 +312,10 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 
 	// DVB LNBf IF and DiSeqC switch settings
 
-	int satNumber = 0;	// No DiseqC Switch
+	int satNumber = -1;	// No DiseqC Switch
 
 	if (config->configuration == DvbConfigBase::DiseqcSwitch)
-		satNumber = config->lnbNumber + 1;
+		satNumber = config->lnbNumber;
 
 	// FIXME: add support for SCR/Unicable
 	if (!backend->satSetup(config->currentLnb.alias, satNumber, 0))
@@ -325,6 +325,7 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 
 	switch (config->configuration) {
 	case DvbConfigBase::DiseqcSwitch:
+	case DvbConfigBase::NoDiseqc:
 		// Everything was already prepared via satSetup().
 		break;
 
@@ -709,10 +710,19 @@ void DvbDevice::frontendEvent()
 
 			if ((scale != DvbBackendDevice::NotSupported) && (signal < 15)) {
 				// signal too weak
-				qInfo("Tuning failed (signal too weak) on %.2f MHz", backend->getFrqMHz());
+				qInfo("Signal too weak on %.2f MHz", backend->getFrqMHz());
+			/*
+			 * FIXME: ignoring a too weak signal is not so easy,
+			 * as it depends on the scale, and scale is broken on
+			 * several drivers. Also, signal itself is not a good
+			 * indicator of the quality. Better to just print a
+			 * warning, and not fail.
+			 */
+#if 0
 				setDeviceState(DeviceIdle);
 				autoTransponder.setTransmissionType(DvbTransponderBase::Invalid);
 				return;
+#endif
 			}
 
 			if (carry && ((capabilities & DvbTFecAuto) == 0)) {
