@@ -53,7 +53,7 @@ DvbRecordingDialog::DvbRecordingDialog(DvbManager *manager_, QWidget *parent) :
 	setLayout(mainLayout);
 	mainLayout->addWidget(mainWidget);
 
-	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
 	connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
 	connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
@@ -306,12 +306,11 @@ QVariant DvbRecordingTableModel::data(const QModelIndex &index, int role) const
 				return QLocale().toString((recording->begin.toLocalTime()), QLocale::ShortFormat);
 			case 3:
 				return recording->duration.toString("HH:mm");
-			case 4: {
+			case 4:
 				if (recording->disabled) {
-					return QString("Disabled");
-				}
-				return QString("Enabled");
+					return i18n("Disabled");
 				}
+				return i18n("Enabled");
 			}
 			break;
 		}
